@@ -838,8 +838,9 @@ class Aggregator:
         self.agg_load = sum(house_load.values())
 
         if self.agg_load >= self.daily_peak:
+            print(self.timestep, self.daily_peak)
             self.daily_peak = self.agg_load
-            self.contribution2peak = {k:max(v,house_load[k]/self.daily_peak) for k,v in self.contribution2peak.items()}
+            self.contribution2peak = {k:house_load[k]/self.daily_peak for k,v in self.contribution2peak.items()}
 
         self.forecast_load = np.sum(self.forecast_house_load)
         self.agg_cost = agg_cost
