@@ -116,7 +116,7 @@ class WH:
             cons = self.add_constraints(enforce_bounds=False)
             obj = cp.Minimize(cp.sum(self.temp_wh_max - self.temp_wh_ev))
             prob = cp.Problem(obj, cons)
-            prob.solve(solver=self.hems.solver, verbose=True)
+            prob.solve(solver=self.hems.solver, verbose=False)
 
     def override_p_wh(self, cmd):
         """
